import asyncio
import time

from aiohttp import ClientSession

from . import log
from .args import parse_args


async def cli_client(url):
    while True:
        sentence = input("> ")
        async with ClientSession() as session:
            async with session.post("http://localhost:8080", json=sentence) as response:
                try:
                    print(await response.json())
                except Exception as ex:
                    print(ex)
                    print(await response.text())


async def bench(url):
    index = 0.0
    # Wait until server is up
    await asyncio.sleep(2)
    duration_limit = 15.0
    time_start = time.time()
    log.info("Benchmarking.")
    async with ClientSession() as session:
        while True:
            index += 1
            try:
                async with session.get(url.rstrip("/") + "/stat"):
                    pass
                time_end = time.time()
                duration = time_end - time_start
                if duration >= duration_limit:
                    break
            except Exception as ex:
                log.exception(ex)
                await asyncio.sleep(1)
    log.info(
        f"{index / duration_limit} requests per second. Made {index} requests in total in duration of {duration} seconds."
    )


def cli_bench():
    args = parse_args()
    asyncio.run(bench(args.url))


def main():
    args = parse_args()
    asyncio.run(cli_client(args.url))


if __name__ == "__main__":
    main()
